==> smartdoc-1.0.0.20020701.zip: src/jp/gr/java_conf/jaba2/tmodel/TTypeLocal.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2002  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.tmodel;

import java.util.*;
import java.sql.*;

/**
 * TTypeLocal
 *
 * @since   May. 16, 2002
 * @version May. 16, 2002
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class TTypeLocal implements ITType {
    private String name_;

    public TTypeLocal(String name) {
	name_ = name;
    }

    public String getName() {
	return (name_);
    }

    public String getDDLName() {
	return (name_);
    }

    public int getSQLType() {
	return (Types.JAVA_OBJECT);
    }

    public Class getJavaType() {
	return (Object.class);
    }

    public Object string2Object(String string) {
	return (string);
    }

    public String object2String(Object object) {
	return (object.toString());
    }
}

==> smartdoc-1.0.1.20030714.zip: src/jp/gr/java_conf/jaba2/tmodel/TTypeLocal.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2002  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.tmodel;

import java.util.*;
import java.sql.*;

/**
 * TTypeLocal
 *
 * @since   May. 16, 2002
 * @version Jul.  3, 2002
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class TTypeLocal implements ITType {
    private String name_;
    private Integer param1_;
    private Integer param2_;

    public TTypeLocal(String name) {
	name_ = name;
	param1_ = null;
	param2_ = null;
    }

    public TTypeLocal(String name, int param1) {
	name_ = name;
	param1_ = new Integer(param1);
	param2_ = null;
    }

    public TTypeLocal(String name, int param1, int param2) {
	name_ = name;
	param1_ = new Integer(param1);
	param2_ = new Integer(param2);
    }

    public String getName() {
	return (name_);
    }

    public String getDDLName() {
	if (param2_ != null) {
	    return (name_ + "(" + param1_ + "," + param2_ + ")");
	} else if (param1_ != null) {
	    return (name_ + "(" + param1_ + ")");
	} else {
	    return (name_);
	}
    }

    public int getSQLType() {
	return (Types.JAVA_OBJECT);
    }

    public Class getJavaType() {
	return (Object.class);
    }

    public Object string2Object(String string) {
	return (string);
    }

    public String object2String(Object object) {
	return (object.toString());
    }
}
